#' Example data set
#' 
#' @keywords internal
#'
#'
"tidygate_data"

#' Example gate_list
#' 
#' @keywords internal
#'
#'
"gate_list"

#' Demo gate data
#' 
#' @keywords data
"demo_gate_data"
